@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c 11193 2009-01-14 07:56:46Z diegoe $ */
+/* $Id$ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -340,17 +340,17 @@ auto_update_toggled (GtkToggleButton *button, GWeatherPref *pref)
     soft_set_sensitive (pref->priv->basic_update_spin, toggled);
     gweather_gconf_set_bool(gw_applet->gconf, "auto_update", toggled, NULL);
     if (gw_applet->timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->timeout_tag);
+        g_source_remove(gw_applet->timeout_tag);
     if (gw_applet->suncalc_timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->suncalc_timeout_tag);
+        g_source_remove(gw_applet->suncalc_timeout_tag);
     if (gw_applet->gweather_pref.update_enabled) {
-        gw_applet->timeout_tag = gtk_timeout_add (
-				gw_applet->gweather_pref.update_interval * 1000,
+        gw_applet->timeout_tag = g_timeout_add_seconds (
+				gw_applet->gweather_pref.update_interval,
 				timeout_cb, gw_applet);
 	nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
 	if (nxtSunEvent >= 0)
-	    gw_applet->suncalc_timeout_tag = gtk_timeout_add (
-	    						nxtSunEvent * 1000,
+	    gw_applet->suncalc_timeout_tag = g_timeout_add_seconds (
+	    						nxtSunEvent,
 							suncalc_timeout_cb,
 							gw_applet);
     }
@@ -545,10 +545,10 @@ update_interval_changed (GtkSpinButton *button, GWeatherPref *pref)
     gweather_gconf_set_int(gw_applet->gconf, "auto_update_interval", 
     		               gw_applet->gweather_pref.update_interval, NULL);
     if (gw_applet->timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->timeout_tag);
+        g_source_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
         gw_applet->timeout_tag =  
-        	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
+        	g_timeout_add_seconds (gw_applet->gweather_pref.update_interval,
                                  timeout_cb, gw_applet);
 }
 
@@ -642,8 +642,10 @@ find_location (GtkTreeModel *model, GtkTreeIter *iter, const gchar *location, gb
 
 	if (go_parent) {
 		iter_parent = *iter;
-		if (gtk_tree_model_iter_parent (model, iter, &iter_parent) && gtk_tree_model_iter_next (model, iter)) {
-			return find_location (model, iter, location, TRUE);
+                while (gtk_tree_model_iter_parent (model, iter, &iter_parent)) {
+			if (gtk_tree_model_iter_next (model, iter))
+				return find_location (model, iter, location, TRUE);
+			iter_parent = *iter;
 		}
 	}
 
@@ -710,6 +712,8 @@ find_entry_changed (GtkEditable *entry, GWeatherPref *pref)
 	tree = GTK_TREE_VIEW (pref->priv->tree);
 	model = gtk_tree_view_get_model (tree);
 
+	g_return_if_fail (model != NULL);
+
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
 	gtk_tree_model_get_iter_first (model, &iter);
 
